@@ -4,17 +4,18 @@ sys.path.insert(0, '.')
 from flask import Flask, render_template, redirect, url_for
 from flaskext.script import Manager
 from flaskext.sqlalchemy import SQLAlchemy
-from flaskext.debugtoolbar import DebugToolbarExtension
+from flask_debugtoolbar import DebugToolbarExtension
 
 
 app = Flask(__name__)
 app.config['DEBUG_TB_INTERCEPT_REDIRECTS'] = True
-app.config['DEBUG'] = True
 #app.config['DEBUG_TB_PANELS'] = (
-#    'flaskext.debugtoolbar.panels.headers.HeaderDebugPanel',
-#    'flaskext.debugtoolbar.panels.logger.LoggingPanel',
-#    'flaskext.debugtoolbar.panels.timer.TimerDebugPanel',
+#    'flask_debugtoolbar.panels.headers.HeaderDebugPanel',
+#    'flask_debugtoolbar.panels.logger.LoggingPanel',
+#    'flask_debugtoolbar.panels.timer.TimerDebugPanel',
 #)
+app.config['SECRET_KEY'] = 'asd'
+app.config['DEBUG'] = True
 app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:////tmp/test.db'
 db = SQLAlchemy(app)
 
@@ -37,10 +38,6 @@ def redirect_example():
     response.set_cookie('test_cookie', '1')
     return response
 
-@app.route('/test/<foo>')
-def var_route(foo):
-    return render_template('index.html')
-
 if __name__ == "__main__":
     db.create_all()
 
